summaryrefslogtreecommitdiffstats
path: root/kabc/ldif.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kabc/ldif.cpp
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kabc/ldif.cpp')
-rw-r--r--kabc/ldif.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kabc/ldif.cpp b/kabc/ldif.cpp
index 19895fce5..2b8f4164c 100644
--- a/kabc/ldif.cpp
+++ b/kabc/ldif.cpp
@@ -112,9 +112,9 @@ bool LDIF::splitLine( const TQCString &line, TQString &fieldname, TQByteArray &v
// kdDebug(5700) << "splitLine line: " << TQString::fromUtf8(line) << endl;
- position = line.find( ":" );
+ position = line.tqfind( ":" );
if ( position == -1 ) {
// strange: we did not find a fieldname
fieldname = "";
TQCString str;
str = line.stripWhiteSpace();
@@ -259,7 +259,7 @@ LDIF::ParseVal LDIF::processLine()
retval = EndEntry;
} else if ( attrLower == "add" ) {
mModType = Mod_Add;
- } else if ( attrLower == "replace" ) {
+ } else if ( attrLower == "tqreplace" ) {
mModType = Mod_Replace;
mAttr = TQString::fromUtf8( mVal, mVal.size() );
mVal.resize( 0 );
@@ -112,9 +112,9 @@ bool LDIF::splitLine( const TQCString &line, TQString &fieldname, TQByteArray &v
if ( position == -1 ) {
- // strange: we did not find a fieldname
+ // strange: we did not tqfind a fieldname
fieldname = "";
TQCString str;